<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */

if ( ! function_exists( 'house_state_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since House State Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function house_state_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'house_state_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'house_state_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since House State Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function house_state_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'house_state_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'house_state_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since House State Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function house_state_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'house_state_pro_theme_options[pagination_enable]' )->value();
	}
endif;



/**
 * Check if slider section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options_slider_content_type' )->value();
	return house_state_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options_slider_content_type' )->value();
	return house_state_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options_slider_content_type' )->value();
	return house_state_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if slider separator section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_slider_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'house_state_pro_theme_options_slider_content_type' )->value();
    return house_state_pro_is_slider_section_enable( $control ) && !( 'category' == $content_type );
}




/**
 * Check if about section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[about_section_enable]' )->value() );
}


function house_state_pro_is_about_section_overlay_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[style_about_overlay_enable]' )->value() );
}


/**
 * Check if about section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options_about_content_type' )->value();
	return house_state_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options_about_content_type' )->value();
	return house_state_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}



/**
 * Check if project section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_project_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[project_section_enable]' )->value() );
}


function house_state_pro_is_project_section_overlay_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[style_project_overlay_enable]' )->value() );
}

/**
 * Check if project section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_project_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[project_content_type]' )->value();
	return house_state_pro_is_project_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if project section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_project_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[project_content_type]' )->value();
	return house_state_pro_is_project_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if project section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_project_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[project_content_type]' )->value();
	return house_state_pro_is_project_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if team section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[team_content_type]' )->value();
	return house_state_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[team_content_type]' )->value();
	return house_state_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[team_content_type]' )->value();
	return house_state_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if service section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[service_content_type]' )->value();
	return house_state_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[service_content_type]' )->value();
	return house_state_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[service_content_type]' )->value();
	return house_state_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if blog section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[blog_content_type]' )->value();
	return house_state_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[blog_content_type]' )->value();
	return house_state_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[blog_content_type]' )->value();
	return house_state_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if partner section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_partner_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[partner_section_enable]' )->value() );
}

/**
 * Check if partner section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_partner_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[partner_content_type]' )->value();
	return house_state_pro_is_partner_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if partner section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_partner_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[partner_content_type]' )->value();
	return house_state_pro_is_partner_section_enable( $control ) && ( 'page' == $content_type );
}



/**
 * Check if service section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[counter_section_enable]' )->value() );
}


/**
 * Check if course section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_course_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[course_section_enable]' )->value() );
}

/**
 * Check if course section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_course_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[course_content_type]' )->value();
	return house_state_pro_is_course_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_course_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[course_content_type]' )->value();
	return house_state_pro_is_course_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if course section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_course_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[course_content_type]' )->value();
	return house_state_pro_is_course_section_enable( $control ) && ( 'category' == $content_type );
}


/*========================Latest Products========================*/

/**
 * Check if latest release section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_latest_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[latest_products_section_enable]' )->value() );
}


/**
 * Check if latest release section content type is product category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_latest_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[latest_products_content_type]' )->value();
	return house_state_pro_is_latest_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if latest release section content type is product category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_latest_products_section_content_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[latest_products_content_type]' )->value();
	return house_state_pro_is_latest_products_section_enable( $control ) && ( 'category' == $content_type );
}


/*========================Latest Products========================*/

/**
 * Check if latest release section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_collection_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[collection_section_enable]' )->value() );
}


/**
 * Check if latest release section content type is product category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_collection_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[collection_content_type]' )->value();
	return house_state_pro_is_collection_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if latest release section content type is product category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_collection_section_content_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[collection_content_type]' )->value();
	return house_state_pro_is_collection_section_enable( $control ) && ( 'category' == $content_type );
}


/*========================Recent Product=========================*/

/**
 * Check if recent_products section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_recent_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[recent_products_section_enable]' )->value() );
}

function house_state_pro_is_recent_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[recent_products_content_type]' )->value();
	return house_state_pro_is_recent_products_section_enable( $control ) && ( 'product' == $content_type );
}

function house_state_pro_is_recent_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[recent_products_content_type]' )->value();
	return house_state_pro_is_recent_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*========================Featured Products======================*/


//featured section
function house_state_pro_is_featured_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[featured_products_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/*========================Treanding Products=====================*/


function house_state_pro_is_trending_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[trending_product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if trending_product section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function house_state_pro_is_trending_product_section_content_category_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[trending_content_type_1]' )->value();
	return house_state_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function house_state_pro_is_trending_product_section_content_category_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[trending_content_type_2]' )->value();
	return house_state_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function house_state_pro_is_trending_product_section_content_category_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[trending_content_type_3]' )->value();
	return house_state_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function house_state_pro_is_trending_product_section_content_product_enable_1( $control ) {
		$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[trending_content_type_1]' )->value();
	return house_state_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function house_state_pro_is_trending_product_section_content_product_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[trending_content_type_2]' )->value();
	return house_state_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function house_state_pro_is_trending_product_section_content_product_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[trending_content_type_3]' )->value();
	return house_state_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

/*========================popular Product=========================*/

/**
 * Check if popular_products section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_popular_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[popular_products_section_enable]' )->value() );
}

function house_state_pro_is_popular_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[popular_products_content_type]' )->value();
	return house_state_pro_is_popular_products_section_enable( $control ) && ( 'product' == $content_type );
}

function house_state_pro_is_popular_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[popular_products_content_type]' )->value();
	return house_state_pro_is_popular_products_section_enable( $control ) && ( 'product-category' == $content_type );
}




/**
 * Check if latest_post section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_latest_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[latest_post_section_enable]' )->value() );
}

/**
 * Check if latest_post section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_latest_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[latest_post_content_type]' )->value();
	return house_state_pro_is_latest_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_post section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_latest_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[latest_post_content_type]' )->value();
	return house_state_pro_is_latest_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_post section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_latest_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[latest_post_content_type]' )->value();
	return house_state_pro_is_latest_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_post section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_popular_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[popular_post_section_enable]' )->value() );
}

/**
 * Check if popular_post section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_popular_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[popular_post_content_type]' )->value();
	return house_state_pro_is_popular_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_post section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_popular_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[popular_post_content_type]' )->value();
	return house_state_pro_is_popular_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_post section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_popular_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[popular_post_content_type]' )->value();
	return house_state_pro_is_popular_post_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if three_column_posts section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_three_column_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[three_column_posts_section_enable]' )->value() );
}

/**
 * Check if three_column_posts section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_three_column_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[three_column_posts_content_type]' )->value();
	return house_state_pro_is_three_column_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if three_column_posts section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_three_column_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[three_column_posts_content_type]' )->value();
	return house_state_pro_is_three_column_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if three_column_posts section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_three_column_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[three_column_posts_content_type]' )->value();
	return house_state_pro_is_three_column_posts_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if three_column_posts section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_featured_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[featured_posts_section_enable]' )->value() );
}

/**
 * Check if featured_posts section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_featured_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[featured_posts_content_type]' )->value();
	return house_state_pro_is_featured_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_posts section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_featured_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[featured_posts_content_type]' )->value();
	return house_state_pro_is_featured_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_posts section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_featured_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[featured_posts_content_type]' )->value();
	return house_state_pro_is_featured_posts_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if three_column_posts section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_recent_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[recent_posts_section_enable]' )->value() );
}

/**
 * Check if recent_posts section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_recent_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[recent_posts_content_type]' )->value();
	return house_state_pro_is_recent_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent_posts section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_recent_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[recent_posts_content_type]' )->value();
	return house_state_pro_is_recent_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent_posts section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_recent_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[recent_posts_content_type]' )->value();
	return house_state_pro_is_recent_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if three_column_posts section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_most_viewed_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[most_viewed_section_enable]' )->value() );
}

/**
 * Check if most_viewed section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_most_viewed_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[most_viewed_content_type]' )->value();
	return house_state_pro_is_most_viewed_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if most_viewed section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_most_viewed_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[most_viewed_content_type]' )->value();
	return house_state_pro_is_most_viewed_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most_viewed section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_most_viewed_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[most_viewed_content_type]' )->value();
	return house_state_pro_is_most_viewed_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if three_column_posts section is enabled.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_single_column_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'house_state_pro_theme_options[single_column_posts_section_enable]' )->value() );
}

/**
 * Check if single_column_posts section content type is post.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_single_column_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[single_column_posts_content_type]' )->value();
	return house_state_pro_is_single_column_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if single_column_posts section content type is page.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_single_column_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[single_column_posts_content_type]' )->value();
	return house_state_pro_is_single_column_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if single_column_posts section content type is category.
 *
 * @since House State Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function house_state_pro_is_single_column_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'house_state_pro_theme_options[single_column_posts_content_type]' )->value();
	return house_state_pro_is_single_column_posts_section_enable( $control ) && ( 'category' == $content_type );
}