<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 * @return array An array of default values
 */

function house_state_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$house_state_pro_default_options = array(
		// Color Options
		'header_title_color'			    => '#fff',
		'header_tagline_color'			    => '#fff',
		'header_txt_logo_extra'			    => 'show-all',
		'colorscheme_hue'				    => '#fe463a',
		'colorscheme'					    => 'default',
		'theme_version'						=> 'lite-version',
		'home_layout'						=> 'default-design',

		// typography Options
		'theme_typography' 				    => 'default',
		'body_theme_typography' 		    => 'default',
		
		// loader
		'loader_enable'         		    => (bool) false,
		'loader_icon'         			    => 'default',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
		
		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',
		'menu_sticky'					    => (bool) false,
		'menu_transparent'					=> (bool) false,

		// excerpt options
		'long_excerpt_length'               => 25,
		'read_more_text'           		    => esc_html__( 'Read More', 'house-state-pro' ),

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'house-state-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'house-state-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'house-state-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'sortable' 						    => 'slider,about,project,team,service,blog,partner,counter,course,latest_products,collection,recent_products,featured_products,trending_product,popular_products,latest_post,inner_content,popular_post',

		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'house-state-pro' ),
		'hide_date' 					    => (bool) false,
		'hide_category'					    => (bool) false,
		'blog_layout_design'				=> '',
		'blog_column'						=> 'col-2',


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,
		'single_post_use_featured_image'	=> (bool) false,

		/* Front Page */

		// Slider
		'slider_section_enable'				=> (bool) true,
		'slider_content_type'				=> 'page',
		'slider_section_sub_title'			=> esc_html__('mesmerizing View','house-state-pro'),
		'slider_count'						=> 4,
		'slider_autoplay_enable'			=> (bool) false,
		'slider_btn_txt'                    => esc_html__('START TOUR','house-state-pro'),
		'slider_btn_alt_txt'                => esc_html__('Explore more','house-state-pro'),
		'slider_excerpt'					=> 10,
		'style_sub_title_color'				=> '',
		'style_slider_overlay_enable'		=> true,

		// Slider
		'about_section_enable'				=> (bool) true,
		'about_content_type'				=> 'post',
		'about_btn_txt'                    	=> esc_html__('Exlore More','house-state-pro'),
		'about_excerpt'						=> 10,
		'style_about_overlay_value'			=> 3,
		'style_about_overlay_enable'         => false,


		// project
		'project_section_enable'			=> (bool) true,
		'project_content_type'				=> 'post',
		'project_section_title'				=> esc_html__('Project','house-state-pro'),
		'project_count'						=> 4,
		'project_autoplay_enable'			=> (bool) false,
		'style_project_overlay_enable'         => true,


		// team
		'team_section_enable'				=> (bool) true,
		'team_content_type'					=> 'post',
		'team_section_title'				=> esc_html__('Our Engineering Team','house-state-pro'),
		'team_count'						=> 4,
		'team_autoplay_enable'				=> (bool) false,
		'style_team_overlay_enable'         => true,


		// service
		'service_section_enable'			=> (bool) true,
		'service_content_type'				=> 'post',
		'service_section_title'				=> esc_html__('Our Engineering Service','house-state-pro'),
		'service_count'						=> 3,
		'style_service_overlay_enable'         => true,


		// blog
		'blog_section_enable'				=> (bool) true,
		'blog_content_type'					=> 'post',
		'blog_section_title'				=> esc_html__('Our Blog','house-state-pro'),
		'blog_count'						=> 3,
		'blog_btn_txt'                    	=> esc_html__('START TOUR','house-state-pro'),
		'style_blog_overlay_enable'         => false,

		// partner
		'partner_section_enable'			=> (bool) true,
		'partner_content_type'				=> 'post',
		'partner_count'						=> 6,

		// counter
		'counter_section_enable'			=> (bool) true,
		'counter_section_title'				=> esc_html__('counter','house-state-pro'),
		'counter_count'						=> 4,
		'counter_column'					=> 'col-4',

		// course
		'course_section_enable'				=> (bool) true,
		'course_content_type'				=> 'post',
		'course_section_title'				=> esc_html__('Course','house-state-pro'),
		'course_count'						=> 4,
	
		// latest products
		'latest_products_section_enable'	=> false,
		'latest_products_count'				=> 2,
		'latest_products_content_type'		=> 'category',

		// collection
		'collection_section_enable'	=> false,
		'collection_title'			=> esc_html__('Product Collections','house-state-pro'),
		'collection_btn_label'		=> esc_html__('Shop Now','house-state-pro'),
		'collection_content_type'		=> 'category',

		// recent
		'recent_products_section_enable'	=> false,
		'recent_products_count'				=> 4,
		'recent_products_title'				=> esc_html__('Recent Products','house-state-pro'),
		'recent_products_content_type'		=> 'product-category',

		//featured section
		'featured_products_section_enable'		=> false,

		//trending_product 
		'trending_product_section_enable'				=> false,
		'trending_product_count'						=> 3,

		// popular
		'popular_products_section_enable'	=> false,
		'popular_products_count'				=> 4,
		'popular_products_title'				=> esc_html__('Popular Products','house-state-pro'),
		'popular_products_content_type'		=> 'product-category',

		// latest_post
		'latest_post_section_enable'				=> true,
		'latest_post_content_type'					=> 'post',

		// popular_post
		'popular_post_section_enable'				=> true,
		'popular_post_content_type'					=> 'post',
		'popular_post_section_title'				=> esc_html__('Our Popular Post','house-state-pro'),
		'popular_post_count'						=> 3,
		'popular_post_excerpt'						=> 30,

		// three_column_posts
		'three_column_posts_section_enable'				=> (bool) true,
		'three_column_posts_content_type'				=> 'post',
		'three_column_posts_section_title'				=> esc_html__('Three Column Posts','house-state-pro'),
		'three_column_posts_count'						=> 3,
		'three_column_posts_excerpt'					=> 30,

		// featured
		'featured_posts_section_enable'				=> (bool) true,
		'featured_posts_content_type'					=> 'post',
		'featured_posts_section_title'				=> esc_html__('Featured Posts','house-state-pro'),
		'featured_posts_count'						=> 2,
		'featured_posts_excerpt'					=> 30,

		// recent
		'recent_posts_section_enable'				=> (bool) true,
		'recent_posts_content_type'					=> 'post',
		'recent_posts_section_title'				=> esc_html__('Recent Posts','house-state-pro'),
		'recent_posts_count'						=> 3,
		'recent_posts_excerpt'					=> 30,

		// most_viewed
		'most_viewed_section_enable'				=> (bool) true,
		'most_viewed_content_type'					=> 'post',
		'most_viewed_section_title'				=> esc_html__('Most Viewed Posts','house-state-pro'),
		'most_viewed_count'						=> 2,
		'most_viewed_excerpt'					=> 30,

		// single_column_posts
		'single_column_posts_section_enable'				=> (bool) true,
		'single_column_posts_content_type'				=> 'post',
		'single_column_posts_section_title'				=> esc_html__('Single Column Posts','house-state-pro'),
		'single_column_posts_count'						=> 3,
		'single_column_posts_excerpt'					=> 30,


	);

	$output = apply_filters( 'house_state_pro_default_theme_options', $house_state_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}