<?php
/**
 * Latest Products Section options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */

// Add Latest Products section
$wp_customize->add_section( 'house_state_pro_latest_products_section', array(
	'title'             => esc_html__( 'Latest Products','house-state-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'house-state-pro' ),
	'panel'             => 'house_state_pro_front_page_panel',
) );

// Latest Products content enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[latest_products_section_enable]', array(
	'default'			=> 	$options['latest_products_section_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[latest_products_section_enable]', array(
	'label'             => esc_html__( 'Latest Products Section Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_latest_products_section',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'house_state_pro_theme_options[latest_products_section_enable]', array(
		'selector'            => '#latest-products div.wrapper',
		'settings'            => 'house_state_pro_theme_options[latest_products_section_enable]',
    ) );
}

// content type control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[latest_products_count]', array(
	'default'          	=> $options['latest_products_count'],
	'sanitize_callback' => 'house_state_pro_sanitize_number_range',
	'validate_callback' => 'house_state_pro_validate_latest_products_count',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[latest_products_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 15. Please input the valid number and save. Then refresh the page to see the change.', 'house-state-pro' ),
	'section'           => 'house_state_pro_latest_products_section',
	'active_callback'   => 'house_state_pro_is_latest_products_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 15,
		'style' => 'width: 100px;'
		),
) );

// Latest Products content type control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[latest_products_content_type]', array(
	'default'          	=> $options['latest_products_content_type'],
	'sanitize_callback' => 'house_state_pro_sanitize_select',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[latest_products_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'house-state-pro' ),
	'section'           => 'house_state_pro_latest_products_section',
	'type'				=> 'select',
	'active_callback' 	=> 'house_state_pro_is_latest_products_section_enable',
	'choices'			=> house_state_pro_latest_products_content_type(),
) );



for ( $i = 1; $i <= $options['latest_products_count']; $i++ ) :

	$wp_customize->add_setting(  'house_state_pro_theme_options[latest_products_content_product_category_' . $i . ']', array(
	'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new House_State_Pro_Dropdown_Taxonomies_Control( $wp_customize,'house_state_pro_theme_options[latest_products_content_product_category_' . $i . ']', array(
		'label'             => esc_html__( 'Select Product Category ', 'house-state-pro' ).$i,
		'section'           => 'house_state_pro_latest_products_section',
		'taxonomy'			=> 'product_cat',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'house_state_pro_is_latest_products_section_content_product_category_enable'
	) ) );

	$wp_customize->add_setting(  'house_state_pro_theme_options[latest_products_content_category_' . $i . ']', array(
	'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new House_State_Pro_Dropdown_Taxonomies_Control( $wp_customize,'house_state_pro_theme_options[latest_products_content_category_' . $i . ']', array(
		'label'             => esc_html__( 'Select Category ', 'house-state-pro' ).$i,
		'section'           => 'house_state_pro_latest_products_section',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'house_state_pro_is_latest_products_section_content_enable'
	) ) );


endfor;