<?php
/**
 * partner Section options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */

// Add partner section
$wp_customize->add_section( 'house_state_pro_partner_section', array(
	'title'             => esc_html__( 'partner','house-state-pro' ),
	'description'       => esc_html__( 'partner Section options.', 'house-state-pro' ),
	'panel'             => 'house_state_pro_front_page_panel',
) );


// partner content enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[partner_section_enable]', array(
	'default'			=> 	$options['partner_section_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[partner_section_enable]', array(
	'label'             => esc_html__( 'partner Section Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_partner_section',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );

// partner number control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[partner_count]', array(
	'default'          	=> $options['partner_count'],
	'sanitize_callback' => 'house_state_pro_sanitize_number_range',
	'validate_callback' => 'house_state_pro_validate_partner_count',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[partner_count]', array(
	'label'             => esc_html__( 'Number of Featured', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 15. Please input the valid number and save. Then refresh the page to see the change.', 'house-state-pro' ),
	'section'           => 'house_state_pro_partner_section',
	'active_callback'   => 'house_state_pro_is_partner_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 15,
		'style' => 'width: 100px;'
		),
) );

// partner content type control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[partner_content_type]', array(
	'default'          	=> $options['partner_content_type'],
	'sanitize_callback' => 'house_state_pro_sanitize_select',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[partner_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'house-state-pro' ),
	'section'           => 'house_state_pro_partner_section',
	'type'				=> 'select',
	'active_callback' 	=> 'house_state_pro_is_partner_section_enable',
	'choices'			=> array( 
            'page' 		=> esc_html__( 'Page', 'house-state-pro' ),
            'post' 		=> esc_html__( 'Post', 'house-state-pro' ),
	),
) );


for ( $i = 1; $i <= $options['partner_count']; $i++ ) :

	// partner pages drop down chooser control and setting
	$wp_customize->add_setting( 'house_state_pro_theme_options[partner_content_page_'. $i .']', array(
		'sanitize_callback' => 'house_state_pro_sanitize_page',
	) );

	$wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[partner_content_page_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Page: %d', 'house-state-pro'), $i ),
		'section'           => 'house_state_pro_partner_section',
		'choices'			=> house_state_pro_page_choices(),
		'active_callback'	=> 'house_state_pro_is_partner_section_content_page_enable',
	) ) );

	// partner posts drop down chooser control and setting
	$wp_customize->add_setting( 'house_state_pro_theme_options[partner_content_post_'. $i .']', array(
		'sanitize_callback' => 'house_state_pro_sanitize_page',
	) );

	$wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[partner_content_post_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Post : %d', 'house-state-pro'), $i ),
		'section'           => 'house_state_pro_partner_section',
		'choices'			=> house_state_pro_post_choices(),
		'active_callback'	=> 'house_state_pro_is_partner_section_content_post_enable',
	) ) );

endfor;

$wp_customize->add_setting( 'house_state_pro_theme_options[style_partner_overlay_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'

	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'house_state_pro_theme_options[style_partner_overlay_color]', array(
	'label'             => esc_html__( 'Overlay Color', 'house-state-pro' ),
	'section'           => 'house_state_pro_partner_section',
	) ) );

$wp_customize->add_setting( 'house_state_pro_theme_options[style_partner_overlay_value]', array(
	'default'          	=> 3,
	'sanitize_callback' => 'house_state_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[style_partner_overlay_value]', array(
	'label'             => esc_html__( 'Overlay Value', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Min 0 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'house-state-pro' ),
	'section'           => 'house_state_pro_partner_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 0,
		'max'	=> 9,
		'style' => 'width: 100px;'
		),
) );

$wp_customize->add_setting( 'house_state_pro_theme_options[style_partner_background]', array(
	'sanitize_callback' => 'house_state_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'house_state_pro_theme_options[style_partner_background]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'house-state-pro' ),
		'section'     		=> 'house_state_pro_partner_section',
) ) );

$wp_customize->add_setting( 'house_state_pro_theme_options[style_partner_background_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'house_state_pro_theme_options[style_partner_background_color]', array(
	'label'             => esc_html__( 'Background Color', 'house-state-pro' ),
	'section'           => 'house_state_pro_partner_section',
	) ) );
