<?php
/**
 * Products Collection Section options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */

// Add collection section
$wp_customize->add_section( 'house_state_pro_collection_section', array(
	'title'             => esc_html__( 'Products Collection','house-state-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'house-state-pro' ),
	'panel'             => 'house_state_pro_front_page_panel',
) );

// collection content enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[collection_section_enable]', array(
	'default'			=> 	$options['collection_section_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[collection_section_enable]', array(
	'label'             => esc_html__( 'collection Section Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_collection_section',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'house_state_pro_theme_options[collection_section_enable]', array(
        'selector'            => '#products-collection div.section-header',
        'settings'            => 'house_state_pro_theme_options[collection_section_enable]',
    ) );
}

// collection title setting and control
$wp_customize->add_setting( 'house_state_pro_theme_options[collection_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> 	$options['collection_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[collection_title]', array(
	'label'           	=> esc_html__( 'Title', 'house-state-pro' ),
	'section'        	=> 'house_state_pro_collection_section',
	'active_callback' 	=> 'house_state_pro_is_collection_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'house_state_pro_theme_options[collection_title]', array(
        'selector'            => '#products-collection h2.section-title',
        'settings'            => 'house_state_pro_theme_options[collection_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'house_state_pro_collection_title_partial',
    ) );
}

$wp_customize->add_setting( 'house_state_pro_theme_options[collection_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> 	$options['collection_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[collection_btn_label]', array(
	'label'           	=> esc_html__( 'Btn Label', 'house-state-pro' ),
	'section'        	=> 'house_state_pro_collection_section',
	'active_callback' 	=> 'house_state_pro_is_collection_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'house_state_pro_theme_options[collection_btn_label]', array(
        'selector'            => '#products-collection h2.section-title',
        'settings'            => 'house_state_pro_theme_options[collection_btn_label]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'house_state_pro_collection_btn_label_partial',
    ) );
}

$wp_customize->add_setting( 'house_state_pro_theme_options[collection_content_type]', array(
	'default'          	=> $options['collection_content_type'],
	'sanitize_callback' => 'house_state_pro_sanitize_select',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[collection_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'house-state-pro' ),
	'section'           => 'house_state_pro_collection_section',
	'type'				=> 'select',
	'active_callback' 	=> 'house_state_pro_is_collection_section_enable',
	'choices'			=> house_state_pro_latest_products_content_type(),
) );


for ( $i = 1; $i <= 4; $i++ ) :

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'house_state_pro_theme_options[collection_content_collection_category_'.$i.']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new House_State_Pro_Dropdown_Taxonomies_Control( $wp_customize,'house_state_pro_theme_options[collection_content_collection_category_'.$i.']', array(
		'label'             => esc_html__( 'Select collection Category ', 'house-state-pro' ).$i,
		'section'           => 'house_state_pro_collection_section',
		'taxonomy'			=> 'product_cat',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'house_state_pro_is_collection_section_content_product_category_enable'
	) ) );

	$wp_customize->add_setting(  'house_state_pro_theme_options[collection_content_collection_post_category_'.$i.']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new House_State_Pro_Dropdown_Taxonomies_Control( $wp_customize,'house_state_pro_theme_options[collection_content_collection_post_category_'.$i.']', array(
		'label'             => esc_html__( 'Select collection Category ', 'house-state-pro' ).$i,
		'section'           => 'house_state_pro_collection_section',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'house_state_pro_is_collection_section_content_enable'
	) ) );


	$wp_customize->add_setting( 'house_state_pro_theme_options[collection_banner_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'house_state_pro_theme_options[collection_banner_title_'.$i.']', array(
		'label'           	=> esc_html__( 'Banner Title ', 'house-state-pro' ).$i,
		'section'        	=> 'house_state_pro_collection_section',
		'active_callback' 	=> 'house_state_pro_is_collection_section_enable',
		'type'				=> 'text',
	) );

endfor;