<?php
/**
 * Banner section
 *
 * This is the template for the content of popular_post section
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */
if ( ! function_exists( 'house_state_pro_add_popular_post_section' ) ) :
    /**
    * Add popular_post section
    *
    *@since House State Pro 1.0.0
    */
    function house_state_pro_add_popular_post_section() {
        $options = house_state_pro_get_theme_options();
        // Check if popular_post is enabled on frontpage
        $popular_post_enable = apply_filters( 'house_state_pro_section_status', true, 'popular_post_section_enable' );

        if ( true !== $popular_post_enable ) {
            return false;
        }
        // Get popular_post section details
        $section_details = array();
        $section_details = apply_filters( 'house_state_pro_filter_popular_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular_post section now.
        house_state_pro_render_popular_post_section( $section_details );
}

endif;

if ( ! function_exists( 'house_state_pro_get_popular_post_section_details' ) ) :
    /**
    * popular_post section details.
    *
    * @since House State Pro 1.0.0
    * @param array $input popular_post section details.
    */
    function house_state_pro_get_popular_post_section_details( $input ) {
        $options = house_state_pro_get_theme_options();

        // Content type.
        $popular_post_content_type    = $options['popular_post_content_type'];
        $popular_post_count           = ! empty( $options['popular_post_count'] ) ? $options['popular_post_count'] : 4;
        
        $content = array();
        switch ( $popular_post_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_post_count; $i++ ) {
                    if ( ! empty( $options['popular_post_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_post_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_post_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_post_count; $i++ ) {
                    if ( ! empty( $options['popular_post_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_post_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $popular_post_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['popular_post_category'] ) ? $options['popular_post_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $popular_post_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['author']    = house_state_pro_author();
                $page_post['excerpt']   = house_state_pro_trim_content( $options['popular_post_excerpt'] );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
            $i++;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_post section content details.
add_filter( 'house_state_pro_filter_popular_post_section_details', 'house_state_pro_get_popular_post_section_details' );


if ( ! function_exists( 'house_state_pro_render_popular_post_section' ) ) :
  /**
   * Start popular_post section
   *
   * @return string popular_post content
   * @since House State Pro 1.0.0
   *
   */
   function house_state_pro_render_popular_post_section( $content_details = array() ) {
        $options = house_state_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="magazine-latest-posts">
            <div class="wrapper">
                <div class="section-header">
                    <?php if ( !empty( $options['popular_post_section_title'] ) ): ?>
                        <h2 class="section-title"><?php echo esc_html( $options['popular_post_section_title'] ) ; ?></h2>
                    <?php endif ?>
                </div><!-- .section-header -->

                <div class="col-3 clear">
                    <?php foreach ( $content_details as $content ) : ?>
                    <article>
                        <div class="latest-post-item">
                            <div class="featured-image">
                                <img src="<?php echo esc_url( $content['image'] ) ; ?>">

                               <?php house_state_pro_posted_on( $content['id'] ); ?>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <?php the_category( '', '', $content['id'] ) ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .entry-container -->
                        </div><!-- .latest-post-item -->
                    </article>
                    <?php endforeach; ?>
                </div><!-- .col-3 -->
            </div><!-- .wrapper -->
        </div><!-- #magazine-latest-posts -->       
    <?php
    }    
endif;

