<?php
/**
 * Products collection section
 *
 * This is the template for the content of collection section
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */
if ( ! function_exists( 'house_state_pro_add_collection_section' ) ) :
    /**
    * Add collection section
    *
    *@since House State Pro 1.0.0
    */
    function house_state_pro_add_collection_section() {
    	$options = house_state_pro_get_theme_options();
        // Check if collection is enabled on frontpage
        $collection_enable = apply_filters( 'house_state_pro_section_status', true, 'collection_section_enable' );

        if ( ( true !== $collection_enable) ) {
            return false;
        }

        // Render collection section now.
        house_state_pro_render_collection_section();
    }
endif;

if ( ! function_exists( 'house_state_pro_render_collection_section' ) ) :
  /**
   * Start collection section
   *
   * @return string collection content
   * @since House State Pro 1.0.0
   *
   */
   function house_state_pro_render_collection_section() {
        $options = house_state_pro_get_theme_options();

    ?>
    
    <div id="products-collection" class="relative page-section same-background">
        <div class="wrapper">
            <div class="section-header">
                <?php  if( !empty( $options['collection_title'] ) ): 
                 ?>
                    <h2 class="section-title"><?php echo esc_html( $options['collection_title'] ); ?></h2>
                <?php endif; ?>
                 <span class="separator">
                     <svg>
                      <g>
                        <path stroke="#A38041" stroke-width="3" d="M0 0 l215 0" />
                        <path stroke="#A38041" stroke-width="2" d="M5,100 v-100" />
                        <path stroke="#A38041" stroke-width="2" d="M10,8 v-50" />
                        <path stroke="#A38041" stroke-width="2" d="M15,8 v-50" />
                        <path stroke="#A38041" stroke-width="2" d="M20 0 v600 400" />
                        <path stroke="#A38041" stroke-width="2" d="M25,8 v-50" />
                        <path stroke="#A38041" stroke-width="2" d="M30,8 v-50" />
                        <path stroke="#A38041" stroke-width="2" d="M35 0 v600 400" />
                        <path stroke="#A38041" stroke-width="2" d="M40,8 v-50" />
                        <path stroke="#A38041" stroke-width="2" d="M45,8 v-50" />
                        <path stroke="#A38041" stroke-width="2" d="M50 0 v600 400" />
                        <path stroke="#A38041" stroke-width="2" d="M55,8 v-50" />
                        <path stroke="#A38041" stroke-width="2" d="M60 0 v600 400" />
                      </g>
                    </svg>
                 </span>
             </div><!-- .section-header -->

     <div class="section-content grid col-2">

       <?php for ( $i=1; $i <= 4 ; $i++ ) { 

         if ( $options['collection_content_type'] == 'category') {
            $image = z_taxonomy_image_url( $options['collection_content_collection_post_category_' . $i ] );
            $title = get_cat_name( $options['collection_content_collection_post_category_' . $i ] );
            $category_link = get_category_link( $options['collection_content_collection_post_category_' . $i ] );
        }else if ( $options['collection_content_type'] == 'product-category'){
            $thumbnail_id = get_term_meta(  $options['collection_content_collection_category_'. $i], 'thumbnail_id', true );
            $image = wp_get_attachment_url( $thumbnail_id );
            $category_link = get_term_link( $options['collection_content_collection_category_'. $i], 'product_cat' );
            $title = get_term_by( 'id', $options['collection_content_collection_category_' . $i ], 'product_cat' )->name;
           
            
        }
        ?>

        <article class="grid-item">
            <div class="featured-image" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                <div class="entry-container">
                    <span class="cat-links">
                        <ul class="post-categories">
                            <li><a href="<?php echo esc_url( $category_link ); ?>"><?php echo esc_html( $title ); ?></a></li>
                        </ul>
                    </span><!-- .cat-links -->

                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php echo esc_url( $category_link ); ?>"><?php echo esc_html( $options['collection_banner_title_'.$i] ) ?></a></h2>
                    </header>

                    <?php if ( !empty( $options['collection_btn_label'] ) ): ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url( $category_link ); ?>" class="btn"><?php echo esc_html( $options['collection_btn_label'] ) ?></a>
                        </div><!-- .read-more -->
                    <?php endif ?>
                    
                </div><!-- .entry-container -->
            </div><!-- .featured-image -->
        </article>

        <?php } ?>

    </div><!-- .section-content -->
</div><!-- .wrapper -->
</div><!-- #products-collction -->

    <?php }
endif;